@@ -8,7 +8,7 @@
 
 #include <QTest>
 
-#include "kmime_headers.h"
+#include "headers.h"
 
 using namespace KMime;
 using namespace KMime::Headers;
@@ -147,6 +147,8 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().first(), QByteArray("kloecker@kde.org"));
     QCOMPARE(h->displayNames().first(), QString::fromUtf8("Ingo Klöcker"));
     QCOMPARE(h->asUnicodeString(), QString::fromUtf8("Ingo Klöcker <kloecker@kde.org>"));
+    QCOMPARE(h->as7BitString(false), "Ingo =?UTF-8?B?S2zDtmNrZXI=?= <kloecker@kde.org>");
+    h->setRFC2047Charset("iso-8859-1");
     QCOMPARE(h->as7BitString(false), QByteArray("Ingo =?ISO-8859-1?Q?Kl=F6cker?= <kloecker@kde.org>"));
     delete h;
 
@@ -154,7 +156,7 @@ void HeaderTest::testAddressListHeader()
     // a display name with non-latin1 content in both name components
     h = new Headers::Generics::AddressList();
     const QString testAddress = QString::fromUtf8("Ingö Klöcker <kloecker@kde.org>");
-    h->fromUnicodeString(testAddress, "utf-8");
+    h->fromUnicodeString(testAddress);
     QCOMPARE(h->asUnicodeString(), testAddress);
     delete h;
 
@@ -162,7 +164,7 @@ void HeaderTest::testAddressListHeader()
         // a display name with non-latin1 content in both name components
         h = new Headers::Generics::AddressList();
         const QString testAddress = QString::fromUtf8("\"Rüedi-Huser, Thomas\" <test@test.org>");
-        h->fromUnicodeString(testAddress, "utf-8");
+        h->fromUnicodeString(testAddress);
         QEXPECT_FAIL("", "AddressList::prettyAddresses() does not quote the mailbox correctly", Continue);
         QCOMPARE(h->asUnicodeString(), testAddress);
         delete h;
@@ -176,13 +178,13 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->displayNames().first(), QString::fromUtf8("Ingo Klöcker"));
     delete h;
 
-    // parsing a empty group
+    // parsing an empty group
     h = new Headers::Generics::AddressList();
     h->from7BitString("Undisclosed recipients:;");
     QCOMPARE(h->addresses().count(), 0);
     delete h;
 
-    // parsing and re-assembling a address list with a group
+    // parsing and re-assembling an address list with a group
     h = new Headers::Generics::AddressList();
     h->from7BitString("A Group:Chris Jones <c@a.test>,joe@where.test,John <jdoe@one.test>;");
     QCOMPARE(h->addresses().count(), 3);
@@ -200,12 +202,14 @@ void HeaderTest::testAddressListHeader()
     h->addAddress("c@a.test");
     QCOMPARE(h->addresses().count(), 3);
     QCOMPARE(h->asUnicodeString(), QString::fromUtf8("John <jdoe@one.test>, Ingo Klöcker <kloecker@kde.org>, c@a.test"));
+    QCOMPARE(h->as7BitString(false), QByteArray("John <jdoe@one.test>, Ingo =?UTF-8?B?S2zDtmNrZXI=?= <kloecker@kde.org>, c@a.test"));
+    h->setRFC2047Charset("ISO-8859-1");
     QCOMPARE(h->as7BitString(false), QByteArray("John <jdoe@one.test>, Ingo =?ISO-8859-1?Q?Kl=F6cker?= <kloecker@kde.org>, c@a.test"));
     delete h;
 
     // parsing from utf-8
     h = new Headers::Generics::AddressList();
-    h->fromUnicodeString(QString::fromUtf8("Ingo Klöcker <kloecker@kde.org>"), "utf-8");
+    h->fromUnicodeString(QString::fromUtf8("Ingo Klöcker <kloecker@kde.org>"));
     QCOMPARE(h->addresses().count(), 1);
     QCOMPARE(h->addresses().first(), QByteArray("kloecker@kde.org"));
     QCOMPARE(h->displayNames().first(), QString::fromUtf8("Ingo Klöcker"));
@@ -221,8 +225,8 @@ void HeaderTest::testAddressListHeader()
              QLatin1StringView("Vice@censored.serverkompetenz.net"));
     QCOMPARE(names.takeFirst(),
              QLatin1StringView("President@mail2.censored.net"));
-    // there is an wrong ' ' after the name, but since the header is completely
-    // broken we can be happy it parses at all...
+    // there is a wrong ' ' after the name, but since the header is completely
+    // broken, we can be happy it parses at all...
     QCOMPARE(names.takeFirst(),
              QLatin1StringView("Int\\\\\\\\\\'l Lotto Commission. "));
     auto addrs = h->addresses();
@@ -300,6 +304,8 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->addresses().first(), QByteArray("xalba@clientes.euskaltel.es"));
     QCOMPARE(h->displayNames().first(), QString::fromUtf8("I\u00F1igo Salvador Azurmendi"));
     QCOMPARE(h->asUnicodeString(), QString::fromUtf8("I\u00F1igo Salvador Azurmendi <xalba@clientes.euskaltel.es>"));
+    QCOMPARE(h->as7BitString(false), QByteArray("=?UTF-8?B?ScOxaWdv?= Salvador Azurmendi <xalba@clientes.euskaltel.es>"));
+    h->setRFC2047Charset("ISO-8859-1");
     QCOMPARE(h->as7BitString(false), QByteArray("=?ISO-8859-1?Q?I=F1igo?= Salvador Azurmendi <xalba@clientes.euskaltel.es>"));
     delete h;
 }
@@ -487,16 +493,16 @@ void HeaderTest::testParametrizedHeader()
     // empty header
     h = new Parametrized();
     QVERIFY(h->isEmpty());
-    QVERIFY(!h->hasParameter(QLatin1StringView("foo")));
+    QVERIFY(!h->hasParameter("foo"));
 
     // add a parameter
-    h->setParameter(QStringLiteral("filename"), QStringLiteral("bla.jpg"));
+    h->setParameter(QByteArrayLiteral("filename"), QStringLiteral("bla.jpg"));
     QVERIFY(!h->isEmpty());
-    QVERIFY(h->hasParameter(QLatin1StringView("filename")));
-    QVERIFY(h->hasParameter(QLatin1StringView("FiLeNaMe")));
-    QVERIFY(!h->hasParameter(QLatin1StringView("bla.jpg")));
-    QCOMPARE(h->parameter(QLatin1StringView("filename")),
-             QLatin1StringView("bla.jpg"));
+    QVERIFY(h->hasParameter("filename"));
+    QVERIFY(h->hasParameter("FiLeNaMe"));
+    QVERIFY(!h->hasParameter("bla.jpg"));
+    QCOMPARE(h->parameter("filename"), QLatin1StringView("bla.jpg"));
+    QCOMPARE(h->parameter("FILENAME"), QLatin1StringView("bla.jpg"));
     QCOMPARE(h->as7BitString(false), QByteArray("filename=\"bla.jpg\""));
 
     // clear again
@@ -507,17 +513,14 @@ void HeaderTest::testParametrizedHeader()
     // parse a parameter list
     h = new Parametrized;
     h->from7BitString("filename=genome.jpeg;\n modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\"");
-    QCOMPARE(h->parameter(QLatin1StringView("filename")),
-             QLatin1StringView("genome.jpeg"));
-    QCOMPARE(h->parameter(QLatin1StringView("modification-date")),
-             QLatin1StringView("Wed, 12 Feb 1997 16:29:51 -0500"));
+    QCOMPARE(h->parameter("filename"), QLatin1StringView("genome.jpeg"));
+    QCOMPARE(h->parameter("modification-date"), QLatin1StringView("Wed, 12 Feb 1997 16:29:51 -0500"));
     QCOMPARE(h->as7BitString(false), QByteArray("filename=\"genome.jpeg\"; modification-date=\"Wed, 12 Feb 1997 16:29:51 -0500\""));
     delete h;
 
     // quoting of whitespaces in parameter value
     h = new Parametrized();
-    h->setParameter(QLatin1StringView("boundary"),
-                    QLatin1StringView("simple boundary"));
+    h->setParameter(QByteArrayLiteral("boundary"), QLatin1StringView("simple boundary"));
     QCOMPARE(h->as7BitString(false), QByteArray("boundary=\"simple boundary\""));
     delete h;
 
@@ -1107,8 +1110,8 @@ void HeaderTest::testMissingQuotes()
     ct.from7BitString(str);
     QCOMPARE(ct.mimeType(), QByteArray{ "multipart/signed" });
     QCOMPARE(ct.boundary(), QByteArray{ "nextPart22807781.u8zn2zYrSU" });
-    QCOMPARE(ct.parameter(QStringLiteral("micalg")), QStringLiteral("pgp-sha1"));
-    QCOMPARE(ct.parameter(QStringLiteral("protocol")), QStringLiteral("application/pgp-signature"));
+    QCOMPARE(ct.parameter("micalg"), QStringLiteral("pgp-sha1"));
+    QCOMPARE(ct.parameter("protocol"), QStringLiteral("application/pgp-signature"));
 
 }
 
@@ -1124,7 +1127,7 @@ void HeaderTest::testBug271192()
         QLatin1StringView(" <") + addrSpec + QLatin1StringView(">");
 
     auto h = new Headers::Generics::SingleMailbox();
-    h->fromUnicodeString(mailbox, "utf-8");
+    h->fromUnicodeString(mailbox);
     QCOMPARE(h->displayNames().size(), 1);
     QCOMPARE(h->displayNames().first().toUtf8(),
              displayName.remove(QLatin1StringView("\\")).toUtf8());
@@ -1132,7 +1135,7 @@ void HeaderTest::testBug271192()
     h = nullptr;
 
     auto h2 = new Headers::Generics::MailboxList();
-    h2->fromUnicodeString(mailbox + QLatin1StringView(",") + mailbox, "utf-8");
+    h2->fromUnicodeString(mailbox + QLatin1StringView(",") + mailbox);
     QCOMPARE(h2->displayNames().size(), 2);
     QCOMPARE(h2->displayNames()[0].toUtf8(),
              displayName.remove(QLatin1StringView("\\")).toUtf8());
