@@ -8,7 +8,7 @@
 #include <QTest>
 #include <QDebug>
 #include <QFile>
-#include <kmime_codecs.cpp>
+#include <codecs.cpp>
 
 using namespace KMime;
 
@@ -201,7 +201,7 @@ void MessageTest::missingHeadersTest()
     // Now create a new message, based on the content of the first one.
     // The body of the new message should still be the same.
     // (there was a bug that caused missing mandatory headers to be
-    //  added as a empty newline, which caused parts of the header to
+    //  added as an empty newline, which caused parts of the header to
     //  leak into the body)
     KMime::Message msg2;
     msg2.setContent(msg.encodedContent());
@@ -458,11 +458,8 @@ void MessageTest::testIssue3914()
     KMime::Content *attachedMail =  msg->contents().at(1);
     QCOMPARE(attachedMail->contentType()->mimeType().data(), "message/rfc822");
     QVERIFY(attachedMail->contentDisposition(false));
-    QVERIFY(attachedMail->contentDisposition()->hasParameter(
-        QLatin1StringView("filename")));
-    QVERIFY(attachedMail->contentDisposition()
-                ->parameter(QLatin1StringView("filename"))
-                .isEmpty());
+    QVERIFY(attachedMail->contentDisposition()->hasParameter("filename"));
+    QVERIFY(attachedMail->contentDisposition()->parameter("filename").isEmpty());
 }
 
 void MessageTest::testBug223509()
@@ -544,7 +541,7 @@ void MessageTest::testEncapsulatedMessages()
              encapsulated->storageSize());
 
     // Now change some properties on the encapsulated message
-    encapsulated->subject()->fromUnicodeString(QStringLiteral("New subject"), "us-ascii");
+    encapsulated->subject()->fromUnicodeString(QStringLiteral("New subject"));
     encapsulated->fromUnicodeString(QStringLiteral("New body string."));
 
     // Since we didn't assemble the encapsulated message yet, it should still have the old headers
